@@ -19,34 +19,34 @@ import (
 	corev1 "k8s.io/api/core/v1"
 )
 
-func (p *PluginRegistry) GetPluginRegistryDeploymentSpec() *appsv1.Deployment {
+func (p *PluginRegistryReconciler) getPluginRegistryDeploymentSpec(ctx *deploy.DeployContext) *appsv1.Deployment {
 	registryType := "plugin"
-	registryImage := util.GetValue(p.deployContext.CheCluster.Spec.Server.PluginRegistryImage, deploy.DefaultPluginRegistryImage(p.deployContext.CheCluster))
-	registryImagePullPolicy := corev1.PullPolicy(util.GetValue(string(p.deployContext.CheCluster.Spec.Server.PluginRegistryPullPolicy), deploy.DefaultPullPolicyFromDockerImage(registryImage)))
+	registryImage := util.GetValue(ctx.CheCluster.Spec.Server.PluginRegistryImage, deploy.DefaultPluginRegistryImage(ctx.CheCluster))
+	registryImagePullPolicy := corev1.PullPolicy(util.GetValue(string(ctx.CheCluster.Spec.Server.PluginRegistryPullPolicy), deploy.DefaultPullPolicyFromDockerImage(registryImage)))
 	probePath := "/v3/plugins/"
 	pluginImagesEnv := util.GetEnvByRegExp("^.*plugin_registry_image.*$")
 
 	resources := corev1.ResourceRequirements{
 		Requests: corev1.ResourceList{
 			corev1.ResourceMemory: util.GetResourceQuantity(
-				p.deployContext.CheCluster.Spec.Server.PluginRegistryMemoryRequest,
+				ctx.CheCluster.Spec.Server.PluginRegistryMemoryRequest,
 				deploy.DefaultPluginRegistryMemoryRequest),
 			corev1.ResourceCPU: util.GetResourceQuantity(
-				p.deployContext.CheCluster.Spec.Server.PluginRegistryCpuRequest,
+				ctx.CheCluster.Spec.Server.PluginRegistryCpuRequest,
 				deploy.DefaultPluginRegistryCpuRequest),
 		},
 		Limits: corev1.ResourceList{
 			corev1.ResourceMemory: util.GetResourceQuantity(
-				p.deployContext.CheCluster.Spec.Server.PluginRegistryMemoryLimit,
+				ctx.CheCluster.Spec.Server.PluginRegistryMemoryLimit,
 				deploy.DefaultPluginRegistryMemoryLimit),
 			corev1.ResourceCPU: util.GetResourceQuantity(
-				p.deployContext.CheCluster.Spec.Server.PluginRegistryCpuLimit,
+				ctx.CheCluster.Spec.Server.PluginRegistryCpuLimit,
 				deploy.DefaultPluginRegistryCpuLimit),
 		},
 	}
 
 	return registry.GetSpecRegistryDeployment(
-		p.deployContext,
+		ctx,
 		registryType,
 		registryImage,
 		pluginImagesEnv,
