@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2012-2019 Red Hat, Inc.
+// Copyright (c) 2019-2021 Red Hat, Inc.
 // This program and the accompanying materials are made
 // available under the terms of the Eclipse Public License 2.0
 // which is available at https://www.eclipse.org/legal/epl-2.0/
@@ -149,9 +149,9 @@ func TestGetSecrets(t *testing.T) {
 					},
 				},
 				ClusterAPI: ClusterAPI{
-					Client:          cli,
-					NonCachedClient: cli,
-					Scheme:          scheme.Scheme,
+					Client:           cli,
+					NonCachingClient: cli,
+					Scheme:           scheme.Scheme,
 				},
 			}
 
@@ -178,9 +178,9 @@ func TestSyncSecretToCluster(t *testing.T) {
 			},
 		},
 		ClusterAPI: ClusterAPI{
-			Client:          cli,
-			NonCachedClient: cli,
-			Scheme:          scheme.Scheme,
+			Client:           cli,
+			NonCachingClient: cli,
+			Scheme:           scheme.Scheme,
 		},
 	}
 
